@@ -1,8 +1,8 @@
+from six import python_2_unicode_compatible
 from .base import QuickbooksBaseObject, Ref, CustomField, Address, EmailAddress, CustomerMemo, QuickbooksManagedObject, \
-    QuickbooksTransactionEntity, LinkedTxn, LinkedTxnMixin, MetaData
+    QuickbooksTransactionEntity, LinkedTxn, LinkedTxnMixin
 from .tax import TxnTaxDetail
-from .detailline import DetailLine, SalesItemLine, SubtotalLine, DiscountLine, GroupLine, DescriptionOnlyLine
-from ..mixins import QuickbooksPdfDownloadable, DeleteMixin, SendMixin, VoidMixin
+from .detailline import DetailLine
 
 
 class DeliveryInfo(QuickbooksBaseObject):
@@ -12,8 +12,8 @@ class DeliveryInfo(QuickbooksBaseObject):
         self.DeliveryTime = ""
 
 
-class Invoice(DeleteMixin, QuickbooksPdfDownloadable, QuickbooksManagedObject, QuickbooksTransactionEntity,
-              LinkedTxnMixin, SendMixin, VoidMixin):
+@python_2_unicode_compatible
+class Invoice(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: An Invoice represents a sales form where the customer pays for a product or service later.
 
@@ -31,13 +31,8 @@ class Invoice(DeleteMixin, QuickbooksPdfDownloadable, QuickbooksManagedObject, Q
         "ShipAddr": Address,
         "TxnTaxDetail": TxnTaxDetail,
         "BillEmail": EmailAddress,
-        "BillEmailCc": EmailAddress,
-        "BillEmailBcc": EmailAddress,
         "CustomerMemo": CustomerMemo,
-        "DeliveryInfo": DeliveryInfo,
-        "RecurDataRef": Ref,
-        "TaxExemptionRef": Ref,
-        "MetaData": MetaData
+        "DeliveryInfo": DeliveryInfo
     }
 
     list_dict = {
@@ -46,14 +41,6 @@ class Invoice(DeleteMixin, QuickbooksPdfDownloadable, QuickbooksManagedObject, Q
         "LinkedTxn": LinkedTxn,
     }
 
-    detail_dict = {
-        "SalesItemLineDetail": SalesItemLine,
-        "SubTotalLineDetail": SubtotalLine,
-        "DiscountLineDetail": DiscountLine,
-        "DescriptionOnly": DescriptionOnlyLine,
-        "GroupLineDetail": GroupLine
-    }
-
     qbo_object_name = "Invoice"
 
     def __init__(self):
@@ -61,44 +48,27 @@ class Invoice(DeleteMixin, QuickbooksPdfDownloadable, QuickbooksManagedObject, Q
         self.Deposit = 0
         self.Balance = 0
         self.AllowIPNPayment = True
-        self.AllowOnlineCreditCardPayment = False
-        self.AllowOnlineACHPayment = False
-        self.DocNumber = None
-
+        self.DocNumber = ""
         self.PrivateNote = ""
         self.DueDate = ""
         self.ShipDate = ""
         self.TrackingNum = ""
         self.TotalAmt = ""
-        self.TxnDate = ""
         self.ApplyTaxAfterDiscount = False
         self.PrintStatus = "NotSet"
         self.EmailStatus = "NotSet"
         self.ExchangeRate = 1
         self.GlobalTaxCalculation = "TaxExcluded"
-        self.InvoiceLink = ""
-        self.HomeBalance = 0
-        self.HomeTotalAmt = 0
-        self.FreeFormAddress = False
-
-        self.EInvoiceStatus = None
 
         self.BillAddr = None
         self.ShipAddr = None
         self.BillEmail = None
-        self.BillEmailCc = None
-        self.BillEmailBcc = None
         self.CustomerRef = None
         self.CurrencyRef = None
         self.CustomerMemo = None
         self.DepartmentRef = None
         self.TxnTaxDetail = None
         self.DeliveryInfo = None
-        self.RecurDataRef = None
-        self.SalesTermRef = None
-        self.ShipMethodRef = None
-        self.TaxExemptionRef = None
-        self.MetaData = None
 
         self.CustomField = []
         self.Line = []
@@ -114,19 +84,3 @@ class Invoice(DeleteMixin, QuickbooksPdfDownloadable, QuickbooksManagedObject, Q
         linked_txn.TxnLineId = 1
 
         return linked_txn
-
-    @property
-    def email_sent(self):
-        if self.EmailStatus == "EmailSent":
-            return True
-
-        return False
-
-    def to_ref(self):
-        ref = Ref()
-
-        ref.name = self.DocNumber
-        ref.type = self.qbo_object_name
-        ref.value = self.Id
-
-        return ref
